// The sample contained herein is provided to you "AS IS".
//
// It is furnished by Add-in Express as a simple example and has not been
// thoroughly tested under all conditions. Add-in Express, therefore, cannot
// guarantee its reliability, serviceability or functionality.

unit uUtils;

interface

uses
  Windows, Dialogs, Outlook2000, adxolFormsManager, ActiveX, Forms, SysUtils;

type
  ProjectConsts = class
  public
    class function DevCode: string; // = "D7";
    class function HowtoName: string; // = "Several Forms in the Same Region";
    class function ProjectShortName: string; // = "SeveralForms";
    class function MessageCaption: string; // = HowtoName;
    class function HowtoProjectName: string; // = ProjectShortName + DevCode;
    class function CommandBarName: string; // = HowtoProjectName;
  end;

  Strings = class
    class function AddinModuleOnError: string; // = "An error has been handled in the AddinModule.OnError event";
    class function FormsManagerOnError: string; // = "An error has been handled in the ADXOlFormsManagger.OnError event";
  end;

  Common = class
  public
    class function IndexOfString(source: string; str: string): integer;
    class procedure ShowError(mes: string);
    class procedure ShowMessage(mes: string);
  end;

  HostVersion = (vUnknown, v2000, v2002, v2003, v2007);

  OutlookUtils = class
  public
    class procedure InitOutlookVersion(OutlookApp: OutlookApplication);
    class function OutlookVersion: HostVersion;
  end;

  ADXUtils = class
  public
    class function ConvertToADXExplorerLayout(explorerLayoutText: string): TadxOlExplorerLayout;
    class function ConvertToADXOlInspectorLayout(inspectorLayoutText: string): TadxolInspectorLayout;
    class function ExistsVisibleForm(Item: TadxOlFormsCollectionItem): boolean;
    class function ADXHTMLFileName: string;
  end;


implementation

var
  OutlookUtilsOutlookVersion: HostVersion;



{ ProjectConsts }

class function ProjectConsts.CommandBarName: string;
begin
  result := HowtoProjectName;
end;

class function ProjectConsts.DevCode: string;
begin
  result := 'D7';
end;

class function ProjectConsts.HowtoName: string;
begin
  result := 'Several Forms in the Same Region';
end;

class function ProjectConsts.HowtoProjectName: string;
begin
  result := ProjectShortName + DevCode;
end;

class function ProjectConsts.MessageCaption: string;
begin
  result := HowtoName;
end;

class function ProjectConsts.ProjectShortName: string;
begin
  result := 'SeveralForms';
end;

{ Strings }

class function Strings.AddinModuleOnError: string;
begin
  result := 'An error has been handled in the AddinModule.OnError event';
end;


class function Strings.FormsManagerOnError: string;
begin
  result := 'An error has been handled in the ADXOlFormsManagger.OnError event';
end;



{ Common }

class function Common.IndexOfString(source, str: string): integer;
begin
  result := Pos(str, source);
end;

class procedure Common.ShowError(mes: string);
begin
  MessageBox(0, PChar(mes), PChar(ProjectConsts.MessageCaption), MB_OK or MB_ICONERROR or MB_APPLMODAL);
end;

class procedure Common.ShowMessage(mes: string);
begin
  MessageBox(0, PChar(mes), PChar(ProjectConsts.MessageCaption), MB_OK or MB_APPLMODAL);
end;

{ OutlookUtils }

class procedure OutlookUtils.InitOutlookVersion(
  OutlookApp: _Application);
var
  hostVersion: string;
begin
  if (OutlookApp <> nil) then begin
      hostVersion := OutlookApp.Version;

      if (Common.IndexOfString(hostVersion, '9.0') > 0) then begin
        OutlookUtilsOutlookVersion := v2000;
      end;

      if (Common.IndexOfString(hostVersion, '10.0') > 0) then begin
        OutlookUtilsOutlookVersion := v2002;
      end;

      if (Common.IndexOfString(hostVersion, '11.0') > 0) then begin
        OutlookUtilsOutlookVersion := v2003;
      end;

      if (Common.IndexOfString(hostVersion, '12.0') > 0) then begin
        OutlookUtilsOutlookVersion := v2007;
      end;
  end;
end;

class function OutlookUtils.OutlookVersion: HostVersion;
begin
  result := OutlookUtilsOutlookVersion;
end;

{ ADXUtils }

class function ADXUtils.ADXHTMLFileName: string;
begin
  result := 'ADXOlFormGeneral.html';
end;

class function ADXUtils.ConvertToADXExplorerLayout(
  explorerLayoutText: string): TadxolExplorerLayout;
begin
  result := elUnknown;
  if explorerLayoutText = 'elUnknown'              then result := elUnknown;
  if explorerLayoutText = 'elTopSubpane'           then result := elTopSubpane;
  if explorerLayoutText = 'elBottomSubpane'        then result := elBottomSubpane;
  if explorerLayoutText = 'elRightSubpane'         then result := elRightSubpane;
  if explorerLayoutText = 'elWebViewPane'          then result := elWebViewPane;
  if explorerLayoutText = 'elLeftSubpane'          then result := elLeftSubpane;
  if explorerLayoutText = 'elBottomOutlookBar'     then result := elBottomOutlookBar;
  if explorerLayoutText = 'elBottomNavigationPane' then result := elBottomNavigationPane;
  if explorerLayoutText = 'elBottomTodoBar'        then result := elBottomTodoBar;
  if explorerLayoutText = 'elTopReadingPane'       then result := elTopReadingPane;
  if explorerLayoutText = 'elBottomReadingPane'    then result := elBottomReadingPane;
  if explorerLayoutText = 'elLeftReadingPane'      then result := elLeftReadingPane;
  if explorerLayoutText = 'elRightReadingPane'     then result := elRightReadingPane;
end;

class function ADXUtils.ConvertToADXOlInspectorLayout(
  inspectorLayoutText: string): TadxolInspectorLayout;
begin
  result := ilUnknown;
  if inspectorLayoutText = 'ilUnknown'              then result := ilUnknown;
  if inspectorLayoutText = 'ilTopSubpane'           then result := ilTopSubpane;
  if inspectorLayoutText = 'ilBottomSubpane'        then result := ilBottomSubpane;
  if inspectorLayoutText = 'ilRightSubpane'         then result := ilRightSubpane;
  if inspectorLayoutText = 'ilLeftSubpane'          then result := ilLeftSubpane;
end;

class function ADXUtils.ExistsVisibleForm(Item: TadxOlFormsCollectionItem): boolean;
var
  i: integer;
begin
  result := false;
  for i := 0 to Item.FormInstanceCount - 1 do begin
    if (Item.FormInstances[i].Visible) then begin
      result := true;
      break;
    end;
  end;
end;



end.
